==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/RecurrenceScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.DaysOfWeek
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The recurrence schedule.
 * @property hours The hours.
 * @property minutes The minutes.
 * @property monthDays The month days.
 * @property monthlyOccurrences The monthly occurrences.
 * @property weekDays The days of the week.
 */
public data class RecurrenceScheduleArgs(
    public val hours: Output<List<Int>>? = null,
    public val minutes: Output<List<Int>>? = null,
    public val monthDays: Output<List<Int>>? = null,
    public val monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null,
    public val weekDays: Output<List<DaysOfWeek>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs =
        com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs.builder()
            .hours(hours?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .minutes(minutes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthDays(monthDays?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthlyOccurrences(
                monthlyOccurrences?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .weekDays(
                weekDays?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RecurrenceScheduleArgs].
 */
@PulumiTagMarker
public class RecurrenceScheduleArgsBuilder internal constructor() {
    private var hours: Output<List<Int>>? = null

    private var minutes: Output<List<Int>>? = null

    private var monthDays: Output<List<Int>>? = null

    private var monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null

    private var weekDays: Output<List<DaysOfWeek>>? = null

    /**
     * @param value The hours.
     */
    @JvmName("fhmnuywrbqjrbjip")
    public suspend fun hours(`value`: Output<List<Int>>) {
        this.hours = value
    }

    @JvmName("tyrfhxulmjhhjxyq")
    public suspend fun hours(vararg values: Output<Int>) {
        this.hours = Output.all(values.asList())
    }

    /**
     * @param values The hours.
     */
    @JvmName("chtvamurqdykuykx")
    public suspend fun hours(values: List<Output<Int>>) {
        this.hours = Output.all(values)
    }

    /**
     * @param value The minutes.
     */
    @JvmName("tyfdbodrorcmpsoc")
    public suspend fun minutes(`value`: Output<List<Int>>) {
        this.minutes = value
    }

    @JvmName("vlftmgoyfemvjxkv")
    public suspend fun minutes(vararg values: Output<Int>) {
        this.minutes = Output.all(values.asList())
    }

    /**
     * @param values The minutes.
     */
    @JvmName("hyjesvdfgerccyio")
    public suspend fun minutes(values: List<Output<Int>>) {
        this.minutes = Output.all(values)
    }

    /**
     * @param value The month days.
     */
    @JvmName("fumnmyxffvmwolfu")
    public suspend fun monthDays(`value`: Output<List<Int>>) {
        this.monthDays = value
    }

    @JvmName("xdqkmietcbckankv")
    public suspend fun monthDays(vararg values: Output<Int>) {
        this.monthDays = Output.all(values.asList())
    }

    /**
     * @param values The month days.
     */
    @JvmName("mbpiuflrvdyksjbi")
    public suspend fun monthDays(values: List<Output<Int>>) {
        this.monthDays = Output.all(values)
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("xuceqeesgcxmwrev")
    public suspend fun monthlyOccurrences(`value`: Output<List<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = value
    }

    @JvmName("wuiagxylmwkyyaxc")
    public suspend fun monthlyOccurrences(vararg values: Output<RecurrenceScheduleOccurrenceArgs>) {
        this.monthlyOccurrences = Output.all(values.asList())
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("ebmoynukwlxjpskt")
    public suspend fun monthlyOccurrences(values: List<Output<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = Output.all(values)
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("amybrklcdppwglki")
    public suspend fun weekDays(`value`: Output<List<DaysOfWeek>>) {
        this.weekDays = value
    }

    @JvmName("tlqixroxmwdpmurc")
    public suspend fun weekDays(vararg values: Output<DaysOfWeek>) {
        this.weekDays = Output.all(values.asList())
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("winwxqijyuilopuh")
    public suspend fun weekDays(values: List<Output<DaysOfWeek>>) {
        this.weekDays = Output.all(values)
    }

    /**
     * @param value The hours.
     */
    @JvmName("qdnjggyqsnfagmea")
    public suspend fun hours(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param values The hours.
     */
    @JvmName("sbjpquxdbecirhxi")
    public suspend fun hours(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param value The minutes.
     */
    @JvmName("idwksdqysxfdfulh")
    public suspend fun minutes(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param values The minutes.
     */
    @JvmName("fwqnarumkyeyxkiv")
    public suspend fun minutes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param value The month days.
     */
    @JvmName("onqqklanydukyrod")
    public suspend fun monthDays(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param values The month days.
     */
    @JvmName("murwkdxpsyejhnty")
    public suspend fun monthDays(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("hakmcohbymcmlusf")
    public suspend fun monthlyOccurrences(`value`: List<RecurrenceScheduleOccurrenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("syfnphbfvkkjhalk")
    public suspend
    fun monthlyOccurrences(argument: List<suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("amjswpltalixccda")
    public suspend fun monthlyOccurrences(
        vararg
        argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("wbdfkojjodxkyndw")
    public suspend
    fun monthlyOccurrences(argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("mycdqjhvrnivwgbo")
    public suspend fun monthlyOccurrences(vararg values: RecurrenceScheduleOccurrenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("dcksnqfivnordumd")
    public suspend fun weekDays(`value`: List<DaysOfWeek>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("ionvtqplhipjssyq")
    public suspend fun weekDays(vararg values: DaysOfWeek) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    internal fun build(): RecurrenceScheduleArgs = RecurrenceScheduleArgs(
        hours = hours,
        minutes = minutes,
        monthDays = monthDays,
        monthlyOccurrences = monthlyOccurrences,
        weekDays = weekDays,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/RecurrenceScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs.builder
import com.pulumi.azurenative.datafactory.kotlin.enums.DaysOfWeek
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The recurrence schedule.
 * @property hours The hours.
 * @property minutes The minutes.
 * @property monthDays The month days.
 * @property monthlyOccurrences The monthly occurrences.
 * @property weekDays The days of the week.
 */
public data class RecurrenceScheduleArgs(
    public val hours: Output<List<Int>>? = null,
    public val minutes: Output<List<Int>>? = null,
    public val monthDays: Output<List<Int>>? = null,
    public val monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null,
    public val weekDays: Output<List<DaysOfWeek>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs =
        com.pulumi.azurenative.datafactory.inputs.RecurrenceScheduleArgs.builder()
            .hours(hours?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .minutes(minutes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthDays(monthDays?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthlyOccurrences(
                monthlyOccurrences?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .weekDays(
                weekDays?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RecurrenceScheduleArgs].
 */
@PulumiTagMarker
public class RecurrenceScheduleArgsBuilder internal constructor() {
    private var hours: Output<List<Int>>? = null

    private var minutes: Output<List<Int>>? = null

    private var monthDays: Output<List<Int>>? = null

    private var monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null

    private var weekDays: Output<List<DaysOfWeek>>? = null

    /**
     * @param value The hours.
     */
    @JvmName("sjkvlbblqpoadfqy")
    public suspend fun hours(`value`: Output<List<Int>>) {
        this.hours = value
    }

    @JvmName("ciocefmkhbmqoilx")
    public suspend fun hours(vararg values: Output<Int>) {
        this.hours = Output.all(values.asList())
    }

    /**
     * @param values The hours.
     */
    @JvmName("bwgjcfssuwihollt")
    public suspend fun hours(values: List<Output<Int>>) {
        this.hours = Output.all(values)
    }

    /**
     * @param value The minutes.
     */
    @JvmName("ucbrpohydjrdvare")
    public suspend fun minutes(`value`: Output<List<Int>>) {
        this.minutes = value
    }

    @JvmName("twmfbgdomsqaakgc")
    public suspend fun minutes(vararg values: Output<Int>) {
        this.minutes = Output.all(values.asList())
    }

    /**
     * @param values The minutes.
     */
    @JvmName("poekvlxlfejrtiye")
    public suspend fun minutes(values: List<Output<Int>>) {
        this.minutes = Output.all(values)
    }

    /**
     * @param value The month days.
     */
    @JvmName("hstlnlgblhocwovm")
    public suspend fun monthDays(`value`: Output<List<Int>>) {
        this.monthDays = value
    }

    @JvmName("bihjyprohqjdpekx")
    public suspend fun monthDays(vararg values: Output<Int>) {
        this.monthDays = Output.all(values.asList())
    }

    /**
     * @param values The month days.
     */
    @JvmName("oicdvigwkjjluofn")
    public suspend fun monthDays(values: List<Output<Int>>) {
        this.monthDays = Output.all(values)
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("vqvuwplpdytxmwrn")
    public suspend fun monthlyOccurrences(`value`: Output<List<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = value
    }

    @JvmName("teqsciifaqwamumw")
    public suspend fun monthlyOccurrences(vararg values: Output<RecurrenceScheduleOccurrenceArgs>) {
        this.monthlyOccurrences = Output.all(values.asList())
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("psatfqtfrlrdvyhx")
    public suspend fun monthlyOccurrences(values: List<Output<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = Output.all(values)
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("etcgwsylqlsakmdb")
    public suspend fun weekDays(`value`: Output<List<DaysOfWeek>>) {
        this.weekDays = value
    }

    @JvmName("wavalyuyqnivchua")
    public suspend fun weekDays(vararg values: Output<DaysOfWeek>) {
        this.weekDays = Output.all(values.asList())
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("bvlxxfrurogfmqxh")
    public suspend fun weekDays(values: List<Output<DaysOfWeek>>) {
        this.weekDays = Output.all(values)
    }

    /**
     * @param value The hours.
     */
    @JvmName("xcwuyjrmqpaknkll")
    public suspend fun hours(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param values The hours.
     */
    @JvmName("plvbptbktybpbghx")
    public suspend fun hours(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param value The minutes.
     */
    @JvmName("fehelspirvkmbdre")
    public suspend fun minutes(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param values The minutes.
     */
    @JvmName("wwwqryngnswjdkph")
    public suspend fun minutes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param value The month days.
     */
    @JvmName("ypmarxyonadvaxgb")
    public suspend fun monthDays(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param values The month days.
     */
    @JvmName("oklfwtqocxhllwvk")
    public suspend fun monthDays(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("yeqwadjefhbyspvl")
    public suspend fun monthlyOccurrences(`value`: List<RecurrenceScheduleOccurrenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("rjhrfttoxohrfuby")
    public suspend
    fun monthlyOccurrences(argument: List<suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("qwgchjrgyxjbgnsx")
    public suspend fun monthlyOccurrences(
        vararg
        argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("ixtlmvcqpevdpohb")
    public suspend
    fun monthlyOccurrences(argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("oguyoiwrgkyitaah")
    public suspend fun monthlyOccurrences(vararg values: RecurrenceScheduleOccurrenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("wrugyarkqdgxumhc")
    public suspend fun weekDays(`value`: List<DaysOfWeek>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("jketmbbkmvratnuc")
    public suspend fun weekDays(vararg values: DaysOfWeek) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    internal fun build(): RecurrenceScheduleArgs = RecurrenceScheduleArgs(
        hours = hours,
        minutes = minutes,
        monthDays = monthDays,
        monthlyOccurrences = monthlyOccurrences,
        weekDays = weekDays,
    )
}
